package ch.zhaw.pm2.multichat.client;

import javafx.beans.property.SimpleBooleanProperty;

import java.util.ArrayList;
import java.util.List;

public class ClientMessageList {
    private List<Message> messages = new ArrayList<>();
    private final SimpleBooleanProperty changed = new SimpleBooleanProperty(false);

    public void addMessage(Message message) {
        messages.add(message);
        changed.set(!changed.get());
    }

    public String getFilteredMessages(String filter) {
        StringBuilder result = new StringBuilder();
        boolean showAll = filter == null || filter.isBlank();
        for (Message message : messages) {
            if (showAll || message.matchesFilter(filter)) {
                switch (message.getType()) {
                    case MESSAGE ->
                            result.append(String.format("[%s -> %s] %s\n", message.getSender(), message.getReceiver(), message.getText()));
                    case ERROR -> result.append(String.format("[ERROR] %s\n", message.getText()));
                    case INFO -> result.append(String.format("[INFO] %s\n", message.getText()));
                    default ->
                            result.append(String.format("[ERROR] %s\n", "Unexpected message type: " + message.getType()));
                }
            }
        }
        return result.toString();
    }

    public void clear() {
        messages = new ArrayList<>();
        changed.set(!changed.get());
    }

    public SimpleBooleanProperty getChangedProperty() {
        return changed;
    }

}
